#
# spec file for package tup
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tup
Version:        0.8
Release:        1.1
Summary:        File-based build system
License:        GPL-2.0-only
URL:            http://gittup.org/tup/
Source0:        https://github.com/gittup/tup/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  awk
BuildRequires:  pkgconfig
BuildRequires:  vim
BuildRequires:  pkgconfig(fuse3)
BuildRequires:  pkgconfig(libpcre2-posix)
Requires:       vim

%description
Tup is a file-based build system.
It inputs a list of file changes and a directed acyclic graph (DAG),
then processes the DAG to execute the appropriate commands required
to update dependent files.

%package        doc
Summary:        Documentation for %{name}
Requires:       %{name} = %{version}
BuildArch:      noarch

%description    doc
Documents and examples for %{name}

%prep
%autosetup -p1
sed "s/\`git describe\`/%{version}/" -i src/tup/link.sh

%build
export CFLAGS="%{optflags}"
./build.sh
./build/tup init
./build/tup generate runme.sh
./runme.sh

%install
vimver=$(vim --version|grep ^VIM|awk '{gsub("\\.","",$5); print $5}')
gzip tup.1
mkdir -p %{buildroot}%{_bindir} %{buildroot}%{_mandir}/man1 \
         %{buildroot}%{_datadir}/vim/vim$vimver/syntax \
         %{buildroot}%{_datadir}/vim/vim$vimver/ftdetect
install -m755 tup -t %{buildroot}%{_bindir}
install -m644 tup.1.gz -t %{buildroot}%{_mandir}/man1
install -m644 contrib/syntax/tup.vim -t %{buildroot}%{_datadir}/vim/vim$vimver/syntax
echo 'au BufNewFile,BufRead Tupfile,*.tup setf tup' > %{buildroot}%{_datadir}/vim/vim$vimver/ftdetect/tup.vim
echo -e "%{_datadir}/vim/vim$vimver/syntax/tup.vim\n%{_datadir}/vim/vim$vimver/ftdetect\n" > vim.files
rm docs/html/*.sh docs/html/Tupfile
mv docs/html/pub/*.pdf docs/html/
mv docs/html/pub/*.css docs/html/
rm -rf docs/html/pub

%files -f vim.files
%doc CONTRIBUTING.md README.md
%license COPYING
%{_bindir}/tup
%{_mandir}/man1/tup.1.gz

%files doc
%doc docs/*

%changelog
* Mon Apr  1 2024 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.8
  Backwards incompatibility with variants:
  * The FUSE overlay variants have been removed in favor of
    explicit variants. If you use variants on version v0.7.11 or
    earlier, you may need to update your Tupfiles. See
    https://gittup.org/tup/ex_explicit_variants.html for more
    details.
  New features:
  * 'import' keyword to set a Tupfile variable to an environment
    variable.
  * 'tup compiledb' can create a compile_commands.json for
    third-party tools to see compilation commands.
  * 'tup commandline' shows the commandline used to compile a
    file.
  * 'tup generate' can support building in a separate build
    directory (if the project supports building with variants).
  * 'tup generate' can take an output list to limit what the
    script generates (ie: a partial build script).
  * A single Lua state is now re-used during parsing and doesn't
    need to be reinitialized for every Lua-based Tupfile.
  * Internal mtime tracking is now at nanosecond resolution
    (where supported by the OS) instead of 1-second intervals.
  Dependency updates:
  * Internal Lua version is now 5.4.6
  * Internal SQLite version is now 3.45.2
  * Internal PCRE version is now PCRE2 10.42
  * External PCRE dependency is now libpcre2 instead of libpcre
    (default unless built with CONFIG_TUP_USE_SYSTEM_PCRE=n in
    which case the internal version is used)
  Bug fixes:
  * Fixed a bug that results in tup_entry_rm called on tupid X,
    which still has refcount=1
  * ^o rules that fail with a monitor autoupdate no longer cause
    infinite loops
  * Deleted files are now removed from the transient_list.
- Drop tup-add_archs.patch (no longer necessary)
- Drop tup.rpmlintrc
* Sat May 15 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.7.11
  New features:
  * ^t flag can be used to mark commands with "transient"
    outputs. These outputs are removed after all dependent
    commands have been processed. (See the manual for details if
    you think this will be useful for you)
  * Internal lua version is now 5.4.3
  Bug fixes:
  * Environment variable changes now show in --debug-logging logs
  * Including a lua file from a regular Tupfile no longer breaks
    updating variables with +=
  * Tup now detects if it is running inside of Conemu's
    dependency injection and issues a warning
  * Changing external files now correctly re-parses if
    full_deps=1 (thanks alightr!)
  * 'tup varsed' now works inside a 'tup generate' script
  * Fixes to the progress bar that sometimes showed a non-zero
    ending state.
  * Argument ordering for partial updates is no longer strict
    (both 'tup filename -k' and 'tup -k filename' should work to
    update filename with the keep-going flag enabled).
- Drop tup-32bit.patch (merged upstream)
* Fri Oct 30 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.7.10
  * Fixed several 'tup version' issues with bootstrapped or
    non-git tup
  * Fixed an error in setting PGID for subprocesses
  * Fixed a few issues with generated files that become normal
    (user-created) files
  * Improvements to 'tup generate' build scripts
  * Now uses fuse3 by default, though fuse2 should still work.
    (Setting CONFIG_TUP_SERVER=fuse in tup.config will use
    fuse2 when building tup)
- Refreshed tup-add_archs.patch
- Added tup-32bit.patch
* Sat Jun 13 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to verison 0.7.9
  * !tup_preserve (to copy src files into variants) should now
  work
  * Progress toward better parallelism during the update phase
- Drop Group tags
* Fri Sep 28 2018 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.7.8
  * Fix to support ccache better
  * Fixes to support icecream better
  * Improvements to %%i, %%#b, and %%#B handling
  * Initial support for ignoring unpredictable outputs
    (https://github.com/gittup/tup/issues/182)
  * Now depends on libpcre, unless tup.config contains
    CONFIG_TUP_USE_SYSTEM_PCRE=n
* Sat Jul 28 2018 aloisio@gmx.com
- Update to version 0.7.7
  * Added --debug-logging flag to save build DAGs and file changes
    in .tup/log/
  * Minor bug fixes:
    + LD_PRELOAD dependency checker (now works with clang)
    + Outputs in other directories don't continually reparse if
    the outputs aren't built yet
    + Windows local build issues
    + Partial updates for groups now build dependent groups
    + Partial updates now correctly clear the modify flag on
    normal files
* Sat Apr 14 2018 aloisio@gmx.com
- Update to version 0.7.6 (no changelog supplied)
- Dropped tup-setgroups_before_setuid.patch (no longer necessary)
* Sun Jan 21 2018 jengelh@inai.de
- Remove rhetorics and other-OS mentions from description.
* Thu Oct  6 2016 aloisio@gmx.com
- Added tup.rpmlintrc
- Minor changes
* Wed Oct  5 2016 aloisio@gmx.com
- Backported a118775 as tup-setgroups_before_setuid.patch
  to address missing-call-to-setgroups-before-setuid
* Sun Oct  2 2016 aloisio@gmx.com
- Initial version 0.7.5
